@@ -53,6 +53,7 @@
 #include <math.h>
 #include "nmglobal.h"
 #include "nbench0.h"
+#include "hardware.h"
 
 /*************
 **** main ****
@@ -78,7 +79,7 @@ ulong bnumrun;          /* # of runs */
 #ifdef MAC
         MaxApplZone();
 #endif
-                
+
 #ifdef MACTIMEMGR
 /* Set up high res timer */
 MacHSTdelay=600*1000*1000;      /* Delay is 10 minutes */
@@ -232,8 +233,8 @@ if(global_allstats)
 */
 #ifdef LINUX
 output_string("\nTEST                : Iterations/sec.  : Old Index   : New Index\n");
-output_string(  "                    :                  : Pentium 90* : AMD K6/233*\n");
-output_string(  "--------------------:------------------:-------------:------------\n");
+output_string("                    :                  : Pentium 90* : AMD K6/233*\n");
+output_string("--------------------:------------------:-------------:------------\n");
 #endif
 
 for(i=0;i<NUMTESTS;i++)
@@ -252,7 +253,8 @@ for(i=0;i<NUMTESTS;i++)
 #ifdef LINUX
                 sprintf(buffer," %15.5g  :  %9.2f  :  %9.2f\n",
                         bmean,bmean/bindex[i],bmean/lx_bindex[i]);
-#else		sprintf(buffer,"  Iterations/sec.: %13.2f  Index: %6.2f\n",
+#else
+		sprintf(buffer,"  Iterations/sec.: %13.2f  Index: %6.2f\n",
                         bmean,bmean/bindex[i]);
 #endif
                 output_string(buffer);
@@ -311,6 +313,7 @@ if(global_custrun==0)
         output_string("Baseline (MSDOS*)   : Pentium* 90, 256 KB L2-cache, Watcom* compiler 10.0\n");
 #ifdef LINUX
         output_string("==============================LINUX DATA BELOW===============================\n");
+	hardware(write_to_file, global_ofile);
 #include "sysinfoc.c"
         sprintf(buffer,"MEMORY INDEX        : %.3f\n",
                        pow(lx_memindex,(double).3333333333));
@@ -435,7 +438,7 @@ while(fgets(inbuf,39,cfile)!=(char *)NULL)
         */
         *eptr++='\0';
         strtoupper((char *)&inbuf[0]);
-        i=MAXPARAM;                     
+        i=MAXPARAM;
         do {
                 if(strcmp(inbuf,paramnames[i])==0)
                         break;
@@ -636,7 +639,7 @@ while(fgets(inbuf,39,cfile)!=(char *)NULL)
                 case PF_DONNET: /* DONNET */
                         tests_to_do[TF_NNET]=getflag(eptr);
                         break;
-                    
+
                 case PF_NNETLOOPS:      /* NNETLOOPS */
                         global_nnetstruct.loops=
                                 (ulong)atol(eptr);
@@ -856,14 +859,14 @@ return(0);
   double temp;            /* For doing a swap */
   int is_beaten;          /* Indicates original was beaten */
   int i;                  /* Index */
-  
+
   /*
   ** First calculate original standard deviation
   */
   calc_confidence(scores,c_half_interval,smean,sdev);
   sdev_to_beat=*sdev;
   is_beaten=-1;
-  
+
   /*
   ** Try to beat original score.  We'll come out of this
   ** loop with a flag.
@@ -879,7 +882,7 @@ return(0);
   		sdev_to_beat=*sdev;
   	}
   }
-  
+
   if(is_beaten!=-1)
   {       scores[is_beaten]=*newscore;
   	return(-1);
